@@ -7,9 +7,10 @@ from typing import Union, Optional
 import pandas as pd
 from sqlalchemy.engine.base import Connection, Engine
 
-from econuy import frequent, transform
+from econuy import custom, transform
 from econuy.retrieval import (cpi, nxr, fiscal_accounts, national_accounts,
-                              labor, rxr, commodity_index, reserves, trade)
+                              labor, rxr, commodity_index, reserves, trade,
+                              public_debt, industrial_production, call)
 from econuy.utils import logutil, ops
 
 
@@ -125,9 +126,10 @@ class Session(object):
 
         Parameters
         ----------
-        dataset : {'cpi', 'nxr_monthly', 'nxr_daily', 'fiscal', 'naccounts', \
-                'labor', 'wages', 'comm_index', 'rxr_custom', 'rxr_official', \
-                'reserves_changes', 'trade'}
+        dataset : {'cpi', 'nxr_monthly', 'nxr_daily', 'fiscal', \
+                'public_debt', 'naccounts', 'labor', 'wages', 'rxr_official', \
+                'reserves', 'reserves_changes', 'trade', \
+                'industrial_production', 'call'}
             Type of data to download.
         update : bool, default True
             Whether to update an existing dataset.
@@ -169,12 +171,24 @@ class Session(object):
                              save_loc=save_loc,
                              only_get=self.only_get,
                              **kwargs)
+        elif dataset == "industrial_production":
+            output = industrial_production.get(update_loc=update_loc,
+                                               revise_rows=self.revise_rows,
+                                               save_loc=save_loc,
+                                               only_get=self.only_get,
+                                               **kwargs)
         elif dataset == "fiscal":
             output = fiscal_accounts.get(update_loc=update_loc,
                                          revise_rows=self.revise_rows,
                                          save_loc=save_loc,
                                          only_get=self.only_get,
                                          **kwargs)
+        elif dataset == "public_debt":
+            output = public_debt.get(update_loc=update_loc,
+                                     revise_rows=self.revise_rows,
+                                     save_loc=save_loc,
+                                     only_get=self.only_get,
+                                     **kwargs)
         elif dataset == "nxr_monthly" or dataset == "nxr_m":
             output = nxr.get_monthly(update_loc=update_loc,
                                      revise_rows=self.revise_rows,
@@ -204,23 +218,17 @@ class Session(object):
                                      save_loc=save_loc,
                                      only_get=self.only_get,
                                      **kwargs)
-        elif dataset == "rxr_custom" or dataset == "rxr-custom":
-            output = rxr.get_custom(update_loc=update_loc,
-                                    revise_rows=self.revise_rows,
-                                    save_loc=save_loc,
-                                    only_get=self.only_get,
-                                    **kwargs)
         elif dataset == "rxr_official" or dataset == "rxr-official":
             output = rxr.get_official(update_loc=update_loc,
                                       revise_rows=self.revise_rows,
                                       save_loc=save_loc,
                                       only_get=self.only_get,
                                       **kwargs)
-        elif dataset == "commodity_index" or dataset == "comm_index":
-            output = commodity_index.get(update_loc=update_loc,
-                                         save_loc=save_loc,
-                                         only_get=self.only_get,
-                                         **kwargs)
+        elif dataset == "reserves":
+            output = reserves.get(update_loc=update_loc,
+                                  save_loc=save_loc,
+                                  only_get=self.only_get,
+                                  **kwargs)
         elif dataset == "reserves_changes" or dataset == "reserves_chg":
             output = reserves.get_changes(update_loc=update_loc,
                                           save_loc=save_loc,
@@ -232,6 +240,12 @@ class Session(object):
                                save_loc=save_loc,
                                only_get=self.only_get,
                                **kwargs)
+        elif dataset == "call":
+            output = call.get(update_loc=update_loc,
+                              revise_rows=self.revise_rows,
+                              save_loc=save_loc,
+                              only_get=self.only_get,
+                              **kwargs)
         else:
             raise ValueError("Invalid keyword for 'dataset' parameter.")
 
@@ -240,18 +254,19 @@ class Session(object):
 
         return self
 
-    def get_frequent(self,
-                     dataset: str,
-                     update: bool = True,
-                     save: bool = True,
-                     **kwargs):
+    def get_custom(self,
+                   dataset: str,
+                   update: bool = True,
+                   save: bool = True,
+                   **kwargs):
         """
-        Get frequently used datasets.
+        Get custom datasets.
 
         Parameters
         ----------
-        dataset : {'inflation', 'fiscal', 'labor', 'real_wages', \
-                'net_trade', 'tot'}
+        dataset : {'cpi_measures', 'fiscal', 'labor', 'real_wages', \
+                'net_trade', 'tot', 'net_public_debt', 'commodity_index', \
+                'rxr_custom', 'core_industrial'}
             Type of data to download.
         update : bool, default True
             Whether to update an existing dataset.
@@ -286,36 +301,56 @@ class Session(object):
         else:
             save_loc = None
 
-        if dataset == "inflation":
-            output = frequent.inflation(update_loc=update_loc,
-                                        save_loc=save_loc,
-                                        only_get=self.only_get,
-                                        **kwargs)
-        elif dataset == "fiscal":
-            output = frequent.fiscal(update_loc=update_loc,
-                                     save_loc=save_loc,
-                                     only_get=self.only_get,
-                                     **kwargs)
-        elif dataset == "labor" or dataset == "labour":
-            output = frequent.labor_rate_people(update_loc=update_loc,
-                                                save_loc=save_loc,
-                                                only_get=self.only_get,
-                                                **kwargs)
-        elif dataset == "wages" or dataset == "real_wages":
-            output = frequent.labor_real_wages(update_loc=update_loc,
-                                               save_loc=save_loc,
-                                               only_get=self.only_get,
-                                               **kwargs)
-        elif dataset == "net_trade":
-            output = frequent.trade_balance(update_loc=update_loc,
+        if dataset == "cpi_measures" or dataset == "price_measures":
+            output = custom.cpi_measures(update_loc=update_loc,
+                                         save_loc=save_loc,
+                                         only_get=self.only_get,
+                                         **kwargs)
+        elif dataset == "core_industrial":
+            output = custom.core_industrial(update_loc=update_loc,
                                             save_loc=save_loc,
                                             only_get=self.only_get,
                                             **kwargs)
-        elif dataset == "tot" or dataset == "terms_of_trade":
-            output = frequent.terms_of_trade(update_loc=update_loc,
+        elif dataset == "fiscal":
+            output = custom.fiscal(update_loc=update_loc,
+                                   save_loc=save_loc,
+                                   only_get=self.only_get,
+                                   **kwargs)
+        elif dataset == "net_public_debt":
+            output = custom.net_public_debt(update_loc=update_loc,
+                                            save_loc=save_loc,
+                                            only_get=self.only_get,
+                                            **kwargs)
+        elif dataset == "labor" or dataset == "labour":
+            output = custom.labor_rate_people(update_loc=update_loc,
+                                              save_loc=save_loc,
+                                              only_get=self.only_get,
+                                              **kwargs)
+        elif dataset == "wages" or dataset == "real_wages":
+            output = custom.labor_real_wages(update_loc=update_loc,
                                              save_loc=save_loc,
                                              only_get=self.only_get,
                                              **kwargs)
+        elif dataset == "net_trade":
+            output = custom.trade_balance(update_loc=update_loc,
+                                          save_loc=save_loc,
+                                          only_get=self.only_get,
+                                          **kwargs)
+        elif dataset == "tot" or dataset == "terms_of_trade":
+            output = custom.terms_of_trade(update_loc=update_loc,
+                                           save_loc=save_loc,
+                                           only_get=self.only_get,
+                                           **kwargs)
+        elif dataset == "rxr_custom" or dataset == "rxr-custom":
+            output = rxr.get_custom(update_loc=update_loc,
+                                    save_loc=save_loc,
+                                    only_get=self.only_get,
+                                    **kwargs)
+        elif dataset == "commodity_index" or dataset == "comm_index":
+            output = commodity_index.get(update_loc=update_loc,
+                                         save_loc=save_loc,
+                                         only_get=self.only_get,
+                                         **kwargs)
         else:
             raise ValueError("Invalid keyword for 'dataset' parameter.")
 
@@ -401,19 +436,19 @@ class Session(object):
         Parameters
         ----------
         flavor : {'both', 'seas', 'trend'}
-            Return both seasonally adjusted and trend dataframes or choose between
-            them.
+            Return both seasonally adjusted and trend dataframes or choose
+            between them.
         method : {'x13', 'loess', 'ma'}
-            Decomposition method. ``X13`` refers to X13 ARIMA from the US Census,
-            ``loess`` refers to Loess decomposition and ``ma`` refers to moving
-            average decomposition, in all cases as implemented by
+            Decomposition method. ``X13`` refers to X13 ARIMA from the US
+            Census, ``loess`` refers to Loess decomposition and ``ma`` refers
+            to moving average decomposition, in all cases as implemented by
             `statsmodels <https://www.statsmodels.org/dev/tsa.html>`_.
         force_x13 : bool, default False
             Whether to try different ``outlier`` and ``trading`` parameters
-            in statsmodels' `x13 arima analysis <https://www.statsmodels.org/dev/
-            generated/statsmodels.tsa.x13.x13_arima_analysis.html>`_ for each
-            series that fails. If ``False``, jump to the ``fallback`` method for
-            the whole dataframe at the first error.
+            in statsmodels' `x13 arima analysis <https://www.statsmodels.org/
+            dev/ generated/statsmodels.tsa.x13.x13_arima_analysis.html>`_ for
+            each series that fails. If ``False``, jump to the ``fallback``
+            method for the whole dataframe at the first error.
         fallback : {'loess', 'ma'}
             Decomposition method to fall back to if ``method="x13"`` fails and
             ``force_x13=False``.
@@ -422,9 +457,9 @@ class Session(object):
         outlier : bool, default True
             Whether to automatically detect outliers in X13 ARIMA.
         x13_binary: str, os.PathLike or None, default 'search'
-            Location of the X13 binary. If ``search`` is used, will attempt to find
-            the binary in the project structure. If ``None``, Statsmodels will
-            handle it.
+            Location of the X13 binary. If ``search`` is used, will attempt to
+            find the binary in the project structure. If ``None``, statsmodels
+            will handle it.
         search_parents: int, default 1
             If ``x13_binary=search``, this parameter controls how many parent
             directories to go up before recursively searching for the binary.
@@ -592,7 +627,7 @@ class Session(object):
         else:
             output = transform.base_index(self.dataset, start_date=start_date,
                                           end_date=end_date, base=base)
-        self.logger.info(f"Applied 'base_index' transformation.")
+        self.logger.info("Applied 'base_index' transformation.")
         if self.inplace is True:
             self.dataset = output
             return self
@@ -654,6 +689,6 @@ class Session(object):
 
     def final(self):
         """Return :attr:`dataset` attribute."""
-        self.logger.info(f"Retrieved dataset from Session() object.")
+        self.logger.info("Retrieved dataset from Session() object.")
 
         return self.dataset
