@@ -1,6 +1,6 @@
 import platform
 import warnings
-from datetime import date
+from datetime import date, datetime
 from os import PathLike, getcwd, path
 from pathlib import Path
 from typing import Union, Optional, Tuple
@@ -34,6 +34,9 @@ def convert_usd(df: pd.DataFrame,
     input dataframe's frequency and whether columns represent rolling averages
     or sums.
 
+    If input dataframe's frequency is higher than monthly (daily, business,
+    etc.), resample to monthly frequency.
+
     Parameters
     ----------
     df : pd.DataFrame
@@ -57,7 +60,19 @@ def convert_usd(df: pd.DataFrame,
     Input dataframe measured in US dollars : pd.DataFrame
 
     """
+    if df.columns.get_level_values("Moneda")[0] == "USD":
+        warnings.warn("Input dataframe already in dollars. No transformations"
+                      " made", UserWarning)
+        return df
+
     inferred_freq = pd.infer_freq(df.index)
+    if inferred_freq in ["D", "B", "C", "W", None]:
+        if df.columns.get_level_values("Tipo")[0] == "Flujo":
+            df = df.resample("M").sum()
+        else:
+            df = df.resample("M").mean()
+        inferred_freq = pd.infer_freq(df.index)
+
     nxr_data = nxr.get_monthly(update_loc=update_loc, save_loc=save_loc,
                                only_get=only_get)
 
@@ -97,6 +112,9 @@ def convert_real(df: pd.DataFrame, start_date: Union[str, date, None] = None,
     a range of dates or no period as a base (i.e., period for which the
     average/sum of input dataframe and output dataframe is the same).
 
+    If input dataframe's frequency is higher than monthly (daily, business,
+    etc.), resample to monthly frequency.
+
     Parameters
     ----------
     df : pd.DataFrame
@@ -126,7 +144,19 @@ def convert_real(df: pd.DataFrame, start_date: Union[str, date, None] = None,
     Input dataframe measured at constant prices : pd.DataFrame
 
     """
+    if "Const" in df.columns.get_level_values("Inf. adj.")[0]:
+        warnings.warn("Input dataframe already in real terms. No "
+                      "transformations made", UserWarning)
+        return df
+
     inferred_freq = pd.infer_freq(df.index)
+    if inferred_freq in ["D", "B", "C", "W", None]:
+        if df.columns.get_level_values("Tipo")[0] == "Flujo":
+            df = df.resample("M").sum()
+        else:
+            df = df.resample("M").mean()
+        inferred_freq = pd.infer_freq(df.index)
+
     cpi_data = cpi.get(update_loc=update_loc, save_loc=save_loc,
                        only_get=only_get)
 
@@ -134,26 +164,32 @@ def convert_real(df: pd.DataFrame, start_date: Union[str, date, None] = None,
     cpi_freq = resample(cpi_data, target=inferred_freq,
                         operation="average").iloc[:, [0]]
     cum_periods = int(df.columns.get_level_values("Acum. períodos")[0])
-    cpi_freq = rolling(cpi_freq, periods=cum_periods,
-                       operation="average")
-    cpi_to_use = cpi_freq[cpi_freq.index.isin(df.index)].iloc[:, 0]
+    cpi_to_use = rolling(cpi_freq, periods=cum_periods,
+                         operation="average").squeeze()
 
     if start_date is None:
         converted_df = df.apply(lambda x:
                                 x / cpi_to_use)
         col_text = "Const."
     elif end_date is None:
+        month = df.iloc[df.index.get_loc(start_date, method="nearest")].name
         converted_df = df.apply(
-            lambda x: x / cpi_to_use *
-                      cpi_to_use.iloc[df.index.get_loc(start_date,
-                                                       method="nearest")])
-        col_text = f"Const. {start_date}"
+            lambda x: x / cpi_to_use
+            * cpi_to_use.loc[month])
+        m_start = datetime.strptime(start_date, "%Y-%m-%d").strftime("%Y-%m")
+        col_text = f"Const. {m_start}"
     else:
         converted_df = df.apply(
             lambda x: x / cpi_to_use * cpi_to_use[start_date:end_date].mean()
         )
-        col_text = f"Const. {start_date}_{end_date}"
+        m_start = datetime.strptime(start_date, "%Y-%m-%d").strftime("%Y-%m")
+        m_end = datetime.strptime(end_date, "%Y-%m-%d").strftime("%Y-%m")
+        if m_start == m_end:
+            col_text = f"Const. {m_start}"
+        else:
+            col_text = f"Const. {m_start}_{m_end}"
 
+    converted_df = converted_df.reindex(df.index)
     metadata._set(converted_df, inf_adj=col_text)
 
     return converted_df
@@ -175,6 +211,12 @@ def convert_gdp(df: pd.DataFrame,
     higher than quarterly, GDP will be upsampled and linear interpolation will
     be performed to complete missing data.
 
+    If input dataframe's "Acum." level is not 12 for monthly frequency or 4
+    for quarterly frequency, internally calculate rolling input dataframe.
+
+    If input dataframe's frequency is higher than monthly (daily, business,
+    etc.), resample to monthly frequency.
+
     Parameters
     ----------
     df : pd.DataFrame
@@ -200,22 +242,42 @@ def convert_gdp(df: pd.DataFrame,
     Raises
     ------
     ValueError
-        If frequency of input dataframe not any of 'M', 'MS', 'Q', 'Q-DEC', 'A'
-        or 'A-DEC'.
+        If frequency of input dataframe not any of 'D', 'C', 'W', 'B', 'M',
+        'MS', 'Q', 'Q-DEC', 'A' or 'A-DEC'.
 
     """
+    if df.columns.get_level_values("Unidad")[0] == "% PBI":
+        warnings.warn("Input dataframe already in percent of GDP. No "
+                      "transformations made", UserWarning)
+        return df
+
     inferred_freq = pd.infer_freq(df.index)
     gdp = national_accounts._lin_gdp(update_loc=update_loc,
                                      save_loc=save_loc, only_get=only_get)
-
+    cum = df.columns.get_level_values("Acum. períodos")[0]
     if inferred_freq in ["M", "MS"]:
         gdp = resample(gdp, target=inferred_freq,
                        operation="upsample", interpolation="linear")
-    elif inferred_freq in ["Q", "Q-DEC", "A", "A-DEC"]:
+        if cum != 12 and df.columns.get_level_values("Tipo")[0] == "Flujo":
+            converter = int(12 / cum)
+            df = rolling(df, periods=converter, operation="sum")
+    elif inferred_freq in ["Q", "Q-DEC"]:
         gdp = gdp.resample(inferred_freq, convention="end").asfreq()
+        if cum != 4 and df.columns.get_level_values("Tipo")[0] == "Flujo":
+            converter = int(4 / cum)
+            df = rolling(df, periods=converter, operation="sum")
+    elif inferred_freq in ["A", "A-DEC"]:
+        gdp = gdp.resample(inferred_freq, convention="end").asfreq()
+    elif inferred_freq in ["D", "B", "C", "W", None]:
+        if df.columns.get_level_values("Tipo")[0] == "Flujo":
+            df = df.resample("M").sum()
+        else:
+            df = df.resample("M").mean()
+        gdp = resample(gdp, target="M",
+                       operation="upsample", interpolation="linear")
     else:
-        raise ValueError("Frequency of input dataframe not any of 'M', 'MS', "
-                         "'Q', 'Q-DEC', 'A' or 'A-DEC'.")
+        raise ValueError("Frequency of input dataframe not any of 'D', 'C', "
+                         "'W', 'B', 'M', 'MS', 'Q', 'Q-DEC', 'A' or 'A-DEC'.")
 
     if df.columns.get_level_values("Moneda")[0] == "USD":
         gdp = gdp.iloc[:, 1].to_frame()
@@ -236,10 +298,9 @@ def resample(df: pd.DataFrame, target: str, operation: str = "sum",
     Wrapper for the `resample method <https://pandas.pydata.org/pandas-docs
     stable/reference/api/pandas.DataFrame.resample.html>`_ in Pandas.
 
-    Resample taking into account dataframe ``Type`` so that stock data is not
-    averaged or summed when resampling; only last value of target frequency
-    is considered. Also, trim partial bins, i.e. do not calculate the resampled
-    period if it is not complete.
+    Trim partial bins, i.e. do not calculate the resampled
+    period if it is not complete (unless the input dataframe has no defined
+    frequency, in which case no trimming is done).
 
     Parameters
     ----------
@@ -249,9 +310,9 @@ def resample(df: pd.DataFrame, target: str, operation: str = "sum",
         Target frequency to resample to. See
         `Pandas offset aliases <https://pandas.pydata.org/pandas-docs/stable/
         user_guide/timeseries.html#offset-aliases>`_
-    operation : {'sum', 'average', 'upsample'}
+    operation : {'sum', 'average', 'upsample', 'end'}
         Operation to use for resampling.
-    interpolation : bool, default True
+    interpolation : str, default 'linear'
         Method to use when missing data are produced as a result of resampling.
         See `Pandas interpolation method <https://pandas.pydata.org/pandas-docs
         /stable/reference/api/pandas.Series.interpolate.html>`_
@@ -269,7 +330,7 @@ def resample(df: pd.DataFrame, target: str, operation: str = "sum",
     Warns
     -----
     UserWarning
-        If input dataframe has ``-`` as frequency in its metadata, warn and
+        If input dataframe has ``-`` as type in its metadata, warn and
         set to flow.
 
     """
@@ -277,46 +338,51 @@ def resample(df: pd.DataFrame, target: str, operation: str = "sum",
                       "A-DEC": 1,
                       "Q": 4,
                       "Q-DEC": 4,
-                      "M": 12}
+                      "M": 12,
+                      "W": 52.143,
+                      "W-SUN": 52.143,
+                      "2W": 26.071,
+                      "2W-SUN": 26.071,
+                      "B": 240,
+                      "D": 365}
 
-    if df.columns.get_level_values("Tipo")[0] == "-":
-        warnings.warn("Dataframe has no Type, setting to 'Flujo'", UserWarning)
-        df.columns = df.columns.set_levels(["Flujo"], level="Tipo")
-
-    if df.columns.get_level_values("Tipo")[0] == "Flujo":
-        if operation == "sum":
-            resampled_df = df.resample(target).sum()
-        elif operation == "average":
-            resampled_df = df.resample(target).mean()
-        elif operation == "upsample":
-            resampled_df = df.resample(target).asfreq()
-            resampled_df = resampled_df.interpolate(method=interpolation)
-        else:
-            raise ValueError("Only 'sum', 'average' and 'upsample' "
-                             "are accepted operations")
-
-        cum_periods = int(df.columns.get_level_values("Acum. períodos")[0])
-        if cum_periods != 1:
-            input_notna = df.iloc[:, 0].count()
-            output_notna = resampled_df.iloc[:, 0].count()
-            cum_adj = round(output_notna / input_notna)
-            metadata._set(resampled_df,
-                          cumperiods=int(cum_periods * cum_adj))
-
-    else:
-        resampled_df = df.resample(target, convention="end").asfreq()
+    if operation == "sum":
+        resampled_df = df.resample(target).sum()
+    elif operation == "average":
+        resampled_df = df.resample(target).mean()
+    elif operation == "end":
+        resampled_df = df.resample(target).last()
+    elif operation == "upsample":
+        resampled_df = df.resample(target).last()
         resampled_df = resampled_df.interpolate(method=interpolation)
+    else:
+        raise ValueError("Only 'sum', 'average', 'end' and 'upsample' "
+                         "are accepted operations")
 
-    infer_base = pd.infer_freq(df.index)
-    base_freq = pd_frequencies[infer_base]
-    target_freq = pd_frequencies[target]
-    if target_freq < base_freq:
-        count = int(base_freq / target_freq)
-        proc = df.resample(target).count()
-        proc = proc.loc[proc.iloc[:, 0] == count]
-        resampled_df = resampled_df.reindex(proc.index)
+    cum_periods = int(df.columns.get_level_values("Acum. períodos")[0])
+    if cum_periods != 1:
+        input_notna = df.iloc[:, 0].count()
+        output_notna = resampled_df.iloc[:, 0].count()
+        cum_adj = round(output_notna / input_notna)
+        metadata._set(resampled_df,
+                      cumperiods=int(cum_periods * cum_adj))
+
+    if operation in ["sum", "average", "end"]:
+        infer_base = pd.infer_freq(df.index)
+        try:
+            base_freq = pd_frequencies[infer_base]
+            target_freq = pd_frequencies[target]
+            if target_freq < base_freq:
+                count = int(base_freq / target_freq)
+                proc = df.resample(target).count()
+                proc = proc.loc[proc.iloc[:, 0] >= count]
+                resampled_df = resampled_df.reindex(proc.index)
+        except KeyError:
+            warnings.warn("No bin trimming performed because frequencies "
+                          "could not be assigned a numeric value", UserWarning)
 
     metadata._set(resampled_df)
+    resampled_df = resampled_df.dropna(how="all")
 
     return resampled_df
 
@@ -353,7 +419,14 @@ def rolling(df: pd.DataFrame, periods: Optional[int] = None,
                       "A-DEC": 1,
                       "Q": 4,
                       "Q-DEC": 4,
-                      "M": 12}
+                      "M": 12,
+                      "MS": 12,
+                      "W": 52,
+                      "W-SUN": 52,
+                      "2W": 26,
+                      "2W-SUN": 26,
+                      "B": 260,
+                      "D": 365}
 
     window_operation = {
         "sum": lambda x: x.rolling(window=periods,
@@ -401,14 +474,21 @@ def base_index(df: pd.DataFrame, start_date: Union[str, date],
 
     """
     if end_date is None:
+        month = df.iloc[df.index.get_loc(start_date, method="nearest")].name
         indexed = df.apply(
-            lambda x: x / x.iloc[x.index.get_loc(start_date, method="nearest")]
-                      * base)
-        metadata._set(indexed, unit=f"{start_date}={base}")
+            lambda x: x
+            / x.loc[month] * base)
+        m_start = datetime.strptime(start_date, "%Y-%m-%d").strftime("%Y-%m")
+        metadata._set(indexed, unit=f"{m_start}={base}")
 
     else:
         indexed = df.apply(lambda x: x / x[start_date:end_date].mean() * base)
-        metadata._set(indexed, unit=f"{start_date}_{end_date}={base}")
+        m_start = datetime.strptime(start_date, "%Y-%m-%d").strftime("%Y-%m")
+        m_end = datetime.strptime(end_date, "%Y-%m-%d").strftime("%Y-%m")
+        if m_start == m_end:
+            metadata._set(indexed, unit=f"{m_start}={base}")
+        else:
+            metadata._set(indexed, unit=f"{m_start}_{m_end}={base}")
 
     return indexed
 
@@ -697,10 +777,9 @@ def chg_diff(df: pd.DataFrame, operation: str = "chg",
     inferred_freq = pd.infer_freq(df.index)
 
     type_change = {"last":
-                       {"chg": [lambda x: x.pct_change(periods=1),
-                                "% variación"],
-                        "diff": [lambda x: x.diff(periods=1),
-                                 "Cambio"]},
+                   {"chg": [lambda x: x.pct_change(periods=1),
+                            "% variación"],
+                    "diff": [lambda x: x.diff(periods=1), "Cambio"]},
                    "inter":
                        {"chg": [lambda x: x.pct_change(periods=last_year),
                                 "% variación interanual"],
