@@ -1,4 +1,5 @@
 import shutil
+import datetime as dt
 from os import listdir, remove, path
 from pathlib import Path
 from typing import Tuple
@@ -41,28 +42,15 @@ def test_prices_inflation():
     session = Session(location=TEST_CON)
     assert isinstance(session, Session)
     assert isinstance(session.dataset, pd.DataFrame)
-    inflation = session.get_frequent(dataset="inflation").dataset
+    measures = session.get_custom(dataset="price_measures").dataset
     remove_clutter()
     prices = session.get(dataset="cpi").dataset
-    remove_clutter()
-    inter = transform.chg_diff(prices, period_op="inter")
-    compare = inflation.iloc[:, [1]]
-    inter.columns = compare.columns
-    assert compare.equals(inter)
-    monthly = transform.chg_diff(prices, period_op="last")
-    compare = inflation.iloc[:, [2]]
-    monthly.columns = compare.columns
-    assert compare.equals(monthly)
-    trend, seasadj = transform.decompose(prices, trading=True, outlier=False)
-    monthly_sa = transform.chg_diff(seasadj)
-    compare = inflation.iloc[:, [3]]
-    monthly_sa.columns = compare.columns
-    assert compare.equals(monthly_sa)
-    monthly_trend = transform.chg_diff(trend)
-    compare = inflation.iloc[:, [4]]
-    monthly_trend.columns = compare.columns
-    assert monthly_trend.equals(monthly_trend)
-    remove_clutter()
+    prices = prices.loc[prices.index >= "1997-03-31"]
+    prices = transform.base_index(prices, start_date="2010-12-01",
+                                  end_date="2010-12-31")
+    compare = measures.iloc[:, [0]]
+    compare.columns = prices.columns
+    assert compare.equals(prices)
 
 
 def test_fiscal():
@@ -70,8 +58,8 @@ def test_fiscal():
     session = Session(location=TEST_CON)
     assert isinstance(session, Session)
     assert isinstance(session.dataset, pd.DataFrame)
-    fiscal_tfm = session.get_frequent(dataset="fiscal", aggregation="nfps",
-                                      fss=True, unit="gdp").dataset
+    fiscal_tfm = session.get_custom(dataset="fiscal", aggregation="nfps",
+                                    fss=True, unit="gdp").dataset
     remove_clutter()
     fiscal_ = session.get(dataset="fiscal").dataset
     nfps = fiscal_["nfps"]
@@ -99,8 +87,8 @@ def test_fiscal():
     proc["Egresos: Totales SPNF aj. FSS"] = (proc["Egresos: Totales SPNF"]
                                              - proc["Intereses: FSS"])
     proc["Resultado: Primario SPNF aj. FSS"] = (
-            proc["Resultado: Primario SPNF"]
-            - proc["Ingresos: FSS"])
+        proc["Resultado: Primario SPNF"]
+        - proc["Ingresos: FSS"])
     proc["Resultado: Global SPNF aj. FSS"] = (proc["Resultado: Global SPNF"]
                                               - proc["Ingresos: FSS"]
                                               + proc["Intereses: FSS"])
@@ -115,24 +103,24 @@ def test_fiscal():
     compare_gdp.columns = fiscal_tfm.columns
     assert compare_gdp.equals(fiscal_tfm)
     remove_clutter()
-    fiscal_tfm = session.get_frequent(dataset="fiscal", aggregation="nfps",
-                                      fss=True, unit="usd").dataset
+    fiscal_tfm = session.get_custom(dataset="fiscal", aggregation="nfps",
+                                    fss=True, unit="usd").dataset
     compare_usd = transform.convert_usd(compare)
     compare_usd.columns = fiscal_tfm.columns
     assert compare_usd.equals(fiscal_tfm)
     remove_clutter()
-    fiscal_tfm = session.get_frequent(dataset="fiscal", aggregation="nfps",
-                                      fss=True, unit="real").dataset
+    fiscal_tfm = session.get_custom(dataset="fiscal", aggregation="nfps",
+                                    fss=True, unit="real").dataset
     compare_real = transform.convert_real(compare)
     compare_real.columns = fiscal_tfm.columns
     assert compare_real.equals(fiscal_tfm)
     remove_clutter()
     start_date = "2010-01-31"
     end_date = "2010-12-31"
-    fiscal_tfm = session.get_frequent(dataset="fiscal", aggregation="nfps",
-                                      fss=True, unit="real_usd",
-                                      start_date=start_date,
-                                      end_date=end_date).dataset
+    fiscal_tfm = session.get_custom(dataset="fiscal", aggregation="nfps",
+                                    fss=True, unit="real_usd",
+                                    start_date=start_date,
+                                    end_date=end_date).dataset
     compare_real_usd = transform.convert_real(compare, start_date=start_date,
                                               end_date=end_date)
     xr = nxr.get_monthly(update_loc=None, save_loc=None)
@@ -142,10 +130,10 @@ def test_fiscal():
     assert compare_real_usd.equals(fiscal_tfm)
     remove_clutter()
     with pytest.raises(ValueError):
-        session.get_frequent(dataset="fiscal", aggregation="nfps",
-                             unit="wrong")
+        session.get_custom(dataset="fiscal", aggregation="nfps",
+                           unit="wrong")
     with pytest.raises(ValueError):
-        session.get_frequent(dataset="fiscal", aggregation="wrong")
+        session.get_custom(dataset="fiscal", aggregation="wrong")
     remove_clutter()
     fiscal_ = session.get(dataset="fiscal").dataset
     session.only_get = True
@@ -161,13 +149,16 @@ def test_labor():
     session = Session(location=TEST_CON)
     assert isinstance(session, Session)
     assert isinstance(session.dataset, pd.DataFrame)
-    labor_tfm = session.get_frequent(dataset="labor", seas_adj="trend").dataset
+    labor_tfm = session.get_custom(dataset="labor", seas_adj="trend",
+                                   extend=False).dataset
     labor_tfm = labor_tfm.iloc[:, [0, 1, 2]]
     remove_clutter()
-    labor_ = session.get(dataset="labor").dataset
+    labor_ = session.get(dataset="labor").dataset.iloc[:, [0, 3, 6]]
     session.only_get = True
-    compare = session.get(dataset="labor").dataset
-    assert labor_.round(4).equals(compare.round(4))
+    compare = session.get(dataset="labor").dataset.iloc[:, [0, 3, 6]]
+    compare = transform.decompose(compare, flavor="trend")
+    compare.columns = labor_tfm.columns
+    assert labor_tfm.round(4).equals(compare.round(4))
     remove_clutter()
     session.only_get = False
     labor_trend, labor_sa = transform.decompose(labor_, outlier=True,
@@ -175,20 +166,25 @@ def test_labor():
     labor_trend.columns = labor_tfm.columns
     assert labor_trend.equals(labor_tfm)
     remove_clutter()
-    labor_tfm = session.get_frequent(dataset="labor", seas_adj="seas").dataset
+    labor_tfm = session.get_custom(dataset="labor", seas_adj="seas",
+                                   extend=False).dataset
     labor_tfm = labor_tfm.iloc[:, [0, 1, 2]]
     labor_sa.columns = labor_tfm.columns
     assert labor_sa.equals(labor_tfm)
     remove_clutter()
-    labor_tfm = session.get_frequent(dataset="labor", seas_adj=None).dataset
+    labor_tfm = session.get_custom(dataset="labor", seas_adj=None,
+                                   extend=False).dataset
     compare = labor_.iloc[:, 0].div(labor_.iloc[:, 1]).round(4)
     compare_2 = labor_tfm.iloc[:, 3].div(labor_tfm.iloc[:, 4]).round(4)
     assert compare.equals(compare_2)
     compare = labor_tfm.iloc[:, 3].mul(labor_.iloc[:, 2]).div(100).round(4)
     assert compare.equals(labor_tfm.iloc[:, 5].round(4))
     remove_clutter()
+    labor_ext = session.get_custom(dataset="labor", extend=True).dataset
+    assert len(labor_ext) > len(labor_tfm)
+    remove_clutter()
     with pytest.raises(ValueError):
-        session.get_frequent(dataset="labor", seas_adj="wrong")
+        session.get_custom(dataset="labor", seas_adj="wrong")
 
 
 def test_wages():
@@ -196,8 +192,8 @@ def test_wages():
     session = Session(location=TEST_CON)
     assert isinstance(session, Session)
     assert isinstance(session.dataset, pd.DataFrame)
-    full_wages = session.get_frequent(dataset="real_wages",
-                                      seas_adj="trend").dataset
+    full_wages = session.get_custom(dataset="real_wages",
+                                    seas_adj="trend").dataset
     wages_tfm = full_wages.iloc[:, [0, 1, 2]]
     remove_clutter()
     wages_ = session.get(dataset="wages").dataset
@@ -212,13 +208,13 @@ def test_wages():
     wages_trend.columns = wages_tfm.columns
     assert wages_trend.equals(wages_tfm)
     remove_clutter()
-    full_wages = session.get_frequent(dataset="wages", seas_adj="seas").dataset
+    full_wages = session.get_custom(dataset="wages", seas_adj="seas").dataset
     wages_tfm = full_wages.iloc[:, [0, 1, 2]]
     wages_sa = transform.base_index(wages_sa, start_date="2008-07-31")
     wages_sa.columns = wages_tfm.columns
     assert wages_sa.equals(wages_tfm)
     remove_clutter()
-    full_wages = session.get_frequent(dataset="wages", seas_adj=None).dataset
+    full_wages = session.get_custom(dataset="wages", seas_adj=None).dataset
     real_wages = full_wages.iloc[:, [3, 4, 5]]
     compare = transform.convert_real(wages_)
     compare = transform.base_index(compare, start_date="2008-07-31")
@@ -226,7 +222,7 @@ def test_wages():
     assert real_wages.equals(compare)
     remove_clutter()
     with pytest.raises(ValueError):
-        session.get_frequent(dataset="wages", seas_adj="wrong")
+        session.get_custom(dataset="wages", seas_adj="wrong")
 
 
 def test_naccounts():
@@ -240,6 +236,16 @@ def test_naccounts():
     remove_clutter()
 
 
+def test_call():
+    remove_clutter()
+    session = Session(location=TEST_CON)
+    assert isinstance(session, Session)
+    assert isinstance(session.dataset, pd.DataFrame)
+    call_rate = session.get(dataset="call").dataset
+    assert call_rate.index[0] == dt.datetime(2002, 1, 2)
+    remove_clutter()
+
+
 def test_trade():
     remove_clutter()
     session = Session(location=TEST_CON)
@@ -249,7 +255,7 @@ def test_trade():
     assert isinstance(tb_, dict)
     assert len(tb_) == 12
     remove_clutter()
-    net = session.get_frequent(dataset="net_trade").dataset
+    net = session.get_custom(dataset="net_trade").dataset
     compare = (tb_["tb_x_dest_val"].
                rename(columns={"Total exportaciones": "Total"})
                - tb_["tb_m_orig_val"].
@@ -268,7 +274,7 @@ def test_tot():
     assert isinstance(tb_, dict)
     assert len(tb_) == 12
     remove_clutter()
-    net = session.get_frequent(dataset="tot").dataset
+    net = session.get_custom(dataset="tot").dataset
     compare = (tb_["tb_x_dest_pri"].
                rename(columns={"Total exportaciones": "Total"})
                / tb_["tb_m_orig_pri"].
@@ -281,6 +287,40 @@ def test_tot():
     remove_clutter()
 
 
+def test_public_debt():
+    remove_clutter()
+    session = Session(location=TEST_CON)
+    assert isinstance(session, Session)
+    assert isinstance(session.dataset, pd.DataFrame)
+    debt = session.get(dataset="public_debt").dataset
+    assert isinstance(debt, dict)
+    assert len(debt) == 4
+    net_debt = session.get_custom(dataset="net_public_debt").dataset
+    assert net_debt.index.__len__() < debt["gps"].index.__len__()
+    remove_clutter()
+
+
+def test_industrial_production():
+    remove_clutter()
+    session = Session(location=TEST_CON)
+    assert isinstance(session, Session)
+    assert isinstance(session.dataset, pd.DataFrame)
+    indprod = session.get(dataset="industrial_production").dataset
+    remove_clutter()
+    core = session.get_custom(dataset="core_industrial").dataset
+    core = core.loc[:, ["Núcleo industrial"]]
+    compare = (indprod["Industrias manufactureras sin refinería"]
+               - indprod.loc[:, 1549] * 0.082210446
+               - indprod.loc[:, 2101] * 0.008097608)
+    compare = pd.concat([compare], keys=["Núcleo industrial"],
+                        names=["Indicador"], axis=1)
+    compare = transform.base_index(compare, start_date="2006-01-01",
+                                   end_date="2006-12-31")
+    compare.columns = core.columns
+    assert core.round(2).equals(compare.round(2))
+    remove_clutter()
+
+
 def test_edge():
     remove_clutter()
     session = Session(location=TEST_DIR)
@@ -290,13 +330,13 @@ def test_edge():
     with pytest.raises(ValueError):
         session.get(dataset="wrong")
     with pytest.raises(ValueError):
-        session.get_frequent(dataset="wrong")
+        session.get_custom(dataset="wrong")
     remove_clutter()
     session = Session(location="new_dir")
     assert path.isdir("new_dir")
     shutil.rmtree(session.location)
-    Session(location=TEST_DIR).get_frequent(dataset="inflation",
-                                            update=False, save=False)
+    Session(location=TEST_DIR).get_custom(dataset="price_measures",
+                                          update=False, save=False)
     remove_clutter()
 
 
