@@ -3,6 +3,7 @@ from os import path
 import pytest
 from sqlalchemy import create_engine
 
+from econuy.utils.metadata import _get_sources
 from econuy.retrieval import cpi
 from econuy.utils import sqlutil
 try:
@@ -39,5 +40,12 @@ def test_sqlutil():
                  end_date="2012-01-15")
     sqlutil.read(con=TEST_CON, table_name="nxr_daily",
                  start_date="2011-01-14")
-    sqlutil.read(con=TEST_CON, table_name="nxr_daily",
-                 end_date="2012-01-15")
\ No newline at end of file
+    sqlutil.read(con=TEST_CON, table_name="reserves_chg",
+                 end_date="2012-01-01",
+                 cols=["1. Compras netas de moneda extranjera"])
+
+
+def test_sources():
+    source_1 = _get_sources("tfm_labor_test")
+    source_2 = _get_sources("tfm_labor")
+    assert source_1 == source_2
